/**
 * Copyright (c) 2010 Alois Glomann gnalff@lucubrators.net
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.lucubrators.honeycomb.xml.constraint;

import java.util.HashMap;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import net.lucubrators.honeycomb.xml.constraint.exceptions.UnknownConstraintException;

/**
 * A default implementation for the {@link ConstraintProvider} interface
 * 
 * @author aglomann
 * 
 */
public class DefaultConstraintProvider implements ConstraintProvider {

	private static Logger					log	= LoggerFactory.getLogger(DefaultConstraintProvider.class);
	private final HashMap<String, Object>	constraints;

	public DefaultConstraintProvider() {
		constraints = new HashMap<String, Object>();
	}

	@Override
	public Object getConstraint(final String id) {
		Object object = constraints.get(id);
		if (object == null) {
			throw new UnknownConstraintException("Unknown constraint with id: " + id);
		}
		return object;
	}

	@Override
	public void addConstraint(final String id, final Object constraint) {
		if (constraints.containsKey(id)) {
			log.warn("You are overwriting an already exisiting constraint with id: {}", id);
		}
		constraints.put(id, constraint);
	}

}
