/**
 * Copyright (c) 2010 Alois Glomann gnalff@lucubrators.net
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.lucubrators.honeycomb.xml.controller;

import java.util.HashMap;

import net.lucubrators.honeycomb.xml.controller.exceptions.UnknownControllerException;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * A default implementation of {@link ControllerProvider}
 * 
 * @author aglomann
 * 
 */
public class DefaultControllerProvider implements ControllerProvider {

	private static Logger					log	= LoggerFactory.getLogger(DefaultControllerProvider.class);

	private final HashMap<String, Object>	controllers;

	public DefaultControllerProvider() {
		controllers = new HashMap<String, Object>();
	}

	@Override
	public void addController(final String id, final Object controller) {
		if (controllers.containsKey(id)) {
			log.warn("Controller with id already exists. Will overwrite it! Id is: {}", id);
		}
		controllers.put(id, controller);
	}

	@Override
	public Object getController(final String id) throws UnknownControllerException {
		Object object = controllers.get(id);
		if (object == null) {
			throw new UnknownControllerException("Unknown controller id: " + id);
		}
		return object;
	}

}
